@@ -32,6 +32,14 @@ ERRNO_ENOTSOCK=[errno.ENOTSOCK]
 if hasattr(errno, "WSAENOTSOCK"):
     ERRNO_ENOTSOCK.append(errno.WSAENOTSOCK)
 
+ERRNO_EADDRNOTAVAIL=[errno.EADDRNOTAVAIL]
+if hasattr(errno, "WSAEADDRNOTAVAIL"):
+    ERRNO_EADDRNOTAVAIL.append(errno.WSAEADDRNOTAVAIL)
+
+ERRNO_EADDRINUSE=[errno.EADDRINUSE]
+if hasattr(errno, "WSAEADDRINUSE"):
+    ERRNO_EADDRINUSE.append(errno.WSAEADDRINUSE)
+
 
 def getIpAddress(hostname=None):
     """returns the IP address for the current, or another, hostname"""
@@ -329,8 +337,8 @@ class SocketConnection(object):
     timeout=property(getTimeout, setTimeout)
 
 
-def findUnusedPort(family=socket.AF_INET, socktype=socket.SOCK_STREAM):
-    """Returns an unused port that should be suitable for binding.
+def findProbablyUnusedPort(family=socket.AF_INET, socktype=socket.SOCK_STREAM):
+    """Returns an unused port that should be suitable for binding (likely, but not guaranteed).
     This code is copied from the stdlib's test.test_support module."""
     tempsock = socket.socket(family, socktype)
     port = bindOnUnusedPort(tempsock)
