@@ -66,7 +66,7 @@ class CoreTests(unittest.TestCase):
         except AttributeError:
             pass
 
-    def XXtestConfigParseBool(self):
+    def testConfigParseBool(self):
         config=Pyro4.configuration.Configuration()
         self.assertTrue(type(config.COMPRESSION) is bool)
         os.environ["PYRO_COMPRESSION"]="yes"
@@ -87,11 +87,11 @@ class CoreTests(unittest.TestCase):
         self.assertTrue("LOGLEVEL" in dump)
 
     def testLogInit(self):
-        _=logging.getLogger("Pyro")
+        _=logging.getLogger("Pyro4")
         os.environ["PYRO_LOGLEVEL"]="DEBUG"
         os.environ["PYRO_LOGFILE"]="{stderr}"
         reload(Pyro4)
-        _=logging.getLogger("Pyro")
+        _=logging.getLogger("Pyro4")
         del os.environ["PYRO_LOGLEVEL"]
         del os.environ["PYRO_LOGFILE"]
         reload(Pyro4)
